package com.devassistant.file.controller;

import com.alibaba.fastjson2.JSONObject;
import com.devassistant.file.model.FileRecord;
import com.devassistant.file.service.FileService;
import com.devassistant.framework.common.RestResult;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

@Slf4j
@RestController
@RequiredArgsConstructor
@RequestMapping("file")
public class FileTransmissionController {

    private final FileService fileService;

    /**
     * 上传文件
     *
     * @param file 文件
     * @return 上传结果
     */
    @PostMapping("/upload")
    public RestResult<?> uploadFile(@RequestParam("file") MultipartFile file, HttpServletRequest request) {
        fileService.uploadFile(file, request);
        return RestResult.genSuccessResult();
    }

    /**
     * 获取文件列表
     *
     * @return 文件列表
     */
    @PostMapping("/getFileList")
    public RestResult<?> getFileList() {
        List<FileRecord> fileList = fileService.getFileList();
        return RestResult.genSuccessResult(fileList);
    }

    /**
     * 删除文件
     *
     * @param body 查询条件
     * @return 删除结果
     */
    @PostMapping("/delFile")
    public RestResult<?> delFileList(@RequestBody JSONObject body) {
        Integer id = body.getInteger("id");
        fileService.delFile(id);
        return RestResult.genSuccessResult();
    }

    /**
     * 下载文件
     *
     * @return 文件
     */
    @GetMapping("/downloadFile")
    public RestResult<?> downloadFile(@RequestParam Integer id, HttpServletResponse response) {
        fileService.downloadFile(id, response);
        return RestResult.genSuccessResult();
    }

}
