package com.devassistant.framework.common;

import lombok.Data;

/**
 * 全局规范响应实体类
 *
 * @param <T>
 */
@Data
public class RestResult<T> {

    // 状态码
    private ResponseCode code;

    // 状态说明
    private String message;

    // 业务数据
    private T data;

    private RestResult() {
    }

    public static <T> RestResult<T> genSuccessResult() {
        return genSuccessResult(null);
    }

    public static <T> RestResult<T> genSuccessResult(T data) {
        RestResult<T> restResult = new RestResult<>();
        restResult.setCode(ResponseCode.SUCCESS);
        restResult.setData(data);
        return restResult;
    }

    public static <T> RestResult<T> genErrorResult(ResponseCode code) {
        RestResult<T> restResult = new RestResult<>();
        restResult.setCode(code);
        restResult.setMessage(code.getMsg());
        return restResult;
    }

    public static <T> RestResult<T> genErrorResult(ResponseCode code, String message) {
        RestResult<T> restResult = new RestResult<>();
        restResult.setCode(code);
        restResult.setMessage(message);
        return restResult;
    }

    public static <T> RestResult<T> genErrorResult(String message) {
        RestResult<T> restResult = new RestResult<>();
        restResult.setCode(ResponseCode.SERVER_ERROR);
        restResult.setMessage(message);
        return restResult;
    }
}
