package com.devassistant.framework.config;


import com.alibaba.fastjson2.JSONObject;
import com.devassistant.framework.common.ResponseCode;
import com.devassistant.framework.common.RestResult;
import jakarta.servlet.*;
import jakarta.servlet.annotation.WebFilter;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.servlet.http.HttpSession;
import org.springframework.stereotype.Component;
import org.springframework.web.cors.CorsConfiguration;

import java.io.IOException;
import java.nio.charset.StandardCharsets;

@Component
@WebFilter(filterName = "loginFilter", urlPatterns = "/*")
public class LoginFilter implements Filter {

    @Override
    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException {
        HttpServletRequest httpRequest = (HttpServletRequest) request;
        HttpServletResponse httpResponse = (HttpServletResponse) response;

        String requestURI = ((HttpServletRequest) request).getRequestURI();

        if("/".equals(requestURI)){
            httpResponse.sendRedirect("/index.html");
            return;
        }

        if ("/authentication/login".equals(requestURI) || requestURI.startsWith("/h2-console") || requestURI.startsWith("/index.html") || requestURI.startsWith("/assets")) {
            chain.doFilter(request, response);
            return;
        }

        HttpSession session = httpRequest.getSession();
        Object isLogin = session.getAttribute("isLogin");
        if (isLogin != null && (boolean) isLogin) {
            chain.doFilter(request, response);
            return;
        }

        RestResult<Object> result = RestResult.genErrorResult(ResponseCode.NEED_LOGIN);
        String responseBody = JSONObject.toJSONString(result);
        httpResponse.addHeader("Access-Control-Allow-Credentials", "true");
        httpResponse.addHeader("Access-Control-Allow-Origin", "*");
        httpResponse.addHeader("Access-Control-Allow-Methods", "GET, POST, DELETE, PUT");

        httpResponse.setCharacterEncoding("UTF-8");
        httpResponse.setContentType("application/json;charset=UTF-8");
        httpResponse.setStatus(HttpServletResponse.SC_UNAUTHORIZED);
        ServletOutputStream outputStream = response.getOutputStream();
        outputStream.write(responseBody.getBytes(StandardCharsets.UTF_8));
        outputStream.flush();
        outputStream.close();
    }
}
